@@ -19,18 +19,18 @@ package mockautoscaling
 import (
 	"sync"
 
-	"github.com/aws/aws-sdk-go/service/autoscaling"
-	"github.com/aws/aws-sdk-go/service/autoscaling/autoscalingiface"
+	autoscalingtypes "github.com/aws/aws-sdk-go-v2/service/autoscaling/types"
+	"k8s.io/kops/util/pkg/awsinterfaces"
 )
 
 type MockAutoscaling struct {
 	// Mock out interface
-	autoscalingiface.AutoScalingAPI
+	awsinterfaces.AutoScalingAPI
 
 	mutex             sync.Mutex
-	Groups            map[string]*autoscaling.Group
-	WarmPoolInstances map[string][]*autoscaling.Instance
-	LifecycleHooks    map[string]*autoscaling.LifecycleHook
+	Groups            map[string]*autoscalingtypes.AutoScalingGroup
+	WarmPoolInstances map[string][]autoscalingtypes.Instance
+	LifecycleHooks    map[string]*autoscalingtypes.LifecycleHook
 }
 
-var _ autoscalingiface.AutoScalingAPI = &MockAutoscaling{}
+var _ awsinterfaces.AutoScalingAPI = &MockAutoscaling{}
