@@ -17,6 +17,9 @@ limitations under the License.
 package model
 
 import (
+	"fmt"
+
+	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/nodeup/nodetasks"
 )
@@ -28,11 +31,18 @@ type PrefixBuilder struct {
 var _ fi.NodeupModelBuilder = &PrefixBuilder{}
 
 func (b *PrefixBuilder) Build(c *fi.NodeupModelBuilderContext) error {
-	if !b.Cluster.Spec.IsKopsControllerIPAM() {
+	if !b.IsKopsControllerIPAM() {
 		return nil
 	}
-	c.AddTask(&nodetasks.Prefix{
-		Name: "prefix",
-	})
+	switch b.CloudProvider() {
+	case kops.CloudProviderAWS:
+		c.AddTask(&nodetasks.Prefix{
+			Name: "prefix",
+		})
+	case kops.CloudProviderGCE:
+		// Prefix is assigned by GCE
+	default:
+		return fmt.Errorf("kOps IPAM controller not supported on cloud %q", b.CloudProvider())
+	}
 	return nil
 }
