@@ -131,11 +131,11 @@ type KubeletConfigSpec struct {
 	// computed (such as IPSEC).
 	NetworkPluginMTU *int32 `json:"networkPluginMTU,omitempty" flag:"network-plugin-mtu"`
 	// imageMinimumGCAge is the minimum age for an unused image before it is garbage collected. Default: "2m"
-	ImageMinimumGCAge *string `json:"imageMinimumGCAge,omitempty" flag:"image-minimum-gc-age"`
+	ImageMinimumGCAge *metav1.Duration `json:"imageMinimumGCAge,omitempty"`
 	// imageMaximumGCAge is the maximum age an image can be unused before it is garbage collected.
 	// The default of this field is "0s", which disables this field--meaning images won't be garbage
 	// collected based on being unused for too long. Default: "0s" (disabled)
-	ImageMaximumGCAge *string `json:"imageMaximumGCAge,omitempty" flag:"image-maximum-gc-age"`
+	ImageMaximumGCAge *metav1.Duration `json:"imageMaximumGCAge,omitempty"`
 	// ImageGCHighThresholdPercent is the percent of disk usage after which
 	// image garbage collection is always run.
 	ImageGCHighThresholdPercent *int32 `json:"imageGCHighThresholdPercent,omitempty" flag:"image-gc-high-threshold"`
@@ -1075,7 +1075,6 @@ type NodeProblemDetectorConfig struct {
 	// Default: 80Mi
 	MemoryLimit *resource.Quantity `json:"memoryLimit,omitempty"`
 	// CPULimit of NodeProblemDetector container.
-	// Default: 10m
 	CPULimit *resource.Quantity `json:"cpuLimit,omitempty"`
 }
 
