@@ -21,6 +21,7 @@ import (
 	"sort"
 	"time"
 
+	elbv2types "github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2/types"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/pkg/apis/kops"
@@ -208,7 +209,7 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			Tags:              tags,
 			WellKnownServices: []wellknownservices.WellKnownService{wellknownservices.KubeAPIServer},
 			VPC:               b.LinkToVPC(),
-			Type:              fi.PtrTo("network"),
+			Type:              elbv2types.LoadBalancerTypeEnumNetwork,
 		}
 
 		// Wait for all load balancer components to be created (including network interfaces needed for NoneDNS).
@@ -231,19 +232,19 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			// Configure fast-recovery health-checks
 			HealthCheck: &awstasks.ClassicLoadBalancerHealthCheck{
 				Target:             fi.PtrTo("SSL:443"),
-				Timeout:            fi.PtrTo(int64(5)),
-				Interval:           fi.PtrTo(int64(10)),
-				HealthyThreshold:   fi.PtrTo(int64(2)),
-				UnhealthyThreshold: fi.PtrTo(int64(2)),
+				Timeout:            fi.PtrTo(int32(5)),
+				Interval:           fi.PtrTo(int32(10)),
+				HealthyThreshold:   fi.PtrTo(int32(2)),
+				UnhealthyThreshold: fi.PtrTo(int32(2)),
 			},
 
 			ConnectionSettings: &awstasks.ClassicLoadBalancerConnectionSettings{
-				IdleTimeout: fi.PtrTo(int64(idleTimeout.Seconds())),
+				IdleTimeout: fi.PtrTo(int32(idleTimeout.Seconds())),
 			},
 
 			ConnectionDraining: &awstasks.ClassicLoadBalancerConnectionDraining{
 				Enabled: fi.PtrTo(true),
-				Timeout: fi.PtrTo(int64(300)),
+				Timeout: fi.PtrTo(int32(300)),
 			},
 
 			Tags:              tags,
@@ -265,17 +266,17 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 		switch lbSpec.Type {
 		case kops.LoadBalancerTypeInternal:
 			clb.Scheme = fi.PtrTo("internal")
-			nlb.Scheme = fi.PtrTo("internal")
+			nlb.Scheme = elbv2types.LoadBalancerSchemeEnumInternal
 		case kops.LoadBalancerTypePublic:
 			clb.Scheme = nil
-			nlb.Scheme = fi.PtrTo("internet-facing")
+			nlb.Scheme = elbv2types.LoadBalancerSchemeEnumInternetFacing
 		default:
 			return fmt.Errorf("unknown load balancer Type: %q", lbSpec.Type)
 		}
 
 		if lbSpec.AccessLog != nil {
 			clb.AccessLog = &awstasks.ClassicLoadBalancerAccessLog{
-				EmitInterval:   fi.PtrTo(int64(lbSpec.AccessLog.Interval)),
+				EmitInterval:   fi.PtrTo(int32(lbSpec.AccessLog.Interval)),
 				Enabled:        fi.PtrTo(true),
 				S3BucketName:   lbSpec.AccessLog.Bucket,
 				S3BucketPrefix: lbSpec.AccessLog.BucketPrefix,
@@ -314,12 +315,12 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 					Lifecycle:          b.Lifecycle,
 					VPC:                b.LinkToVPC(),
 					Tags:               groupTags,
-					Protocol:           fi.PtrTo("TCP"),
-					Port:               fi.PtrTo(int64(443)),
+					Protocol:           elbv2types.ProtocolEnumTcp,
+					Port:               fi.PtrTo(int32(443)),
 					Attributes:         groupAttrs,
-					Interval:           fi.PtrTo(int64(10)),
-					HealthyThreshold:   fi.PtrTo(int64(2)),
-					UnhealthyThreshold: fi.PtrTo(int64(2)),
+					Interval:           fi.PtrTo(int32(10)),
+					HealthyThreshold:   fi.PtrTo(int32(2)),
+					UnhealthyThreshold: fi.PtrTo(int32(2)),
 					Shared:             fi.PtrTo(false),
 				}
 				tg.CreateNewRevisionsWith(nlb)
@@ -338,12 +339,12 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 					Lifecycle:          b.Lifecycle,
 					VPC:                b.LinkToVPC(),
 					Tags:               groupTags,
-					Protocol:           fi.PtrTo("TCP"),
-					Port:               fi.PtrTo(int64(wellknownports.KopsControllerPort)),
+					Protocol:           elbv2types.ProtocolEnumTcp,
+					Port:               fi.PtrTo(int32(wellknownports.KopsControllerPort)),
 					Attributes:         groupAttrs,
-					Interval:           fi.PtrTo(int64(10)),
-					HealthyThreshold:   fi.PtrTo(int64(2)),
-					UnhealthyThreshold: fi.PtrTo(int64(2)),
+					Interval:           fi.PtrTo(int32(10)),
+					HealthyThreshold:   fi.PtrTo(int32(2)),
+					UnhealthyThreshold: fi.PtrTo(int32(2)),
 					Shared:             fi.PtrTo(false),
 				}
 				tg.CreateNewRevisionsWith(nlb)
@@ -362,12 +363,12 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 					Lifecycle:          b.Lifecycle,
 					VPC:                b.LinkToVPC(),
 					Tags:               tlsGroupTags,
-					Protocol:           fi.PtrTo("TLS"),
-					Port:               fi.PtrTo(int64(443)),
+					Protocol:           elbv2types.ProtocolEnumTls,
+					Port:               fi.PtrTo(int32(443)),
 					Attributes:         groupAttrs,
-					Interval:           fi.PtrTo(int64(10)),
-					HealthyThreshold:   fi.PtrTo(int64(2)),
-					UnhealthyThreshold: fi.PtrTo(int64(2)),
+					Interval:           fi.PtrTo(int32(10)),
+					HealthyThreshold:   fi.PtrTo(int32(2)),
+					UnhealthyThreshold: fi.PtrTo(int32(2)),
 					Shared:             fi.PtrTo(false),
 				}
 				secondaryTG.CreateNewRevisionsWith(nlb)
@@ -431,10 +432,10 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 				t := &awstasks.SecurityGroupRule{
 					Name:          fi.PtrTo("https-api-elb-" + cidr),
 					Lifecycle:     b.SecurityLifecycle,
-					FromPort:      fi.PtrTo(int64(443)),
+					FromPort:      fi.PtrTo(int32(443)),
 					Protocol:      fi.PtrTo("tcp"),
 					SecurityGroup: lbSG,
-					ToPort:        fi.PtrTo(int64(443)),
+					ToPort:        fi.PtrTo(int32(443)),
 				}
 				t.SetCidrOrPrefix(cidr)
 				AddDirectionalGroupRule(c, t)
@@ -445,8 +446,8 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 				t := &awstasks.SecurityGroupRule{
 					Name:          fi.PtrTo("https-api-elb-8443-" + cidr),
 					Lifecycle:     b.SecurityLifecycle,
-					FromPort:      fi.PtrTo(int64(8443)),
-					ToPort:        fi.PtrTo(int64(8443)),
+					FromPort:      fi.PtrTo(int32(8443)),
+					ToPort:        fi.PtrTo(int32(8443)),
 					Protocol:      fi.PtrTo("tcp"),
 					SecurityGroup: lbSG,
 				}
@@ -461,10 +462,10 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 				t := &awstasks.SecurityGroupRule{
 					Name:          fi.PtrTo("icmpv6-pmtu-api-elb-" + cidr),
 					Lifecycle:     b.SecurityLifecycle,
-					FromPort:      fi.PtrTo(int64(-1)),
+					FromPort:      fi.PtrTo(int32(-1)),
 					Protocol:      fi.PtrTo("icmpv6"),
 					SecurityGroup: lbSG,
-					ToPort:        fi.PtrTo(int64(-1)),
+					ToPort:        fi.PtrTo(int32(-1)),
 				}
 				t.SetCidrOrPrefix(cidr)
 				if t.CIDR == nil {
@@ -475,10 +476,10 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 				t := &awstasks.SecurityGroupRule{
 					Name:          fi.PtrTo("icmp-pmtu-api-elb-" + cidr),
 					Lifecycle:     b.SecurityLifecycle,
-					FromPort:      fi.PtrTo(int64(3)),
+					FromPort:      fi.PtrTo(int32(3)),
 					Protocol:      fi.PtrTo("icmp"),
 					SecurityGroup: lbSG,
-					ToPort:        fi.PtrTo(int64(4)),
+					ToPort:        fi.PtrTo(int32(4)),
 				}
 				t.SetCidrOrPrefix(cidr)
 				if t.IPv6CIDR == nil {
@@ -518,11 +519,11 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			t := &awstasks.SecurityGroupRule{
 				Name:          fi.PtrTo(fmt.Sprintf("tcp-api-cp%s", suffix)),
 				Lifecycle:     b.SecurityLifecycle,
-				FromPort:      fi.PtrTo(int64(8443)),
+				FromPort:      fi.PtrTo(int32(8443)),
 				Protocol:      fi.PtrTo("tcp"),
 				SecurityGroup: masterGroup.Task,
 				SourceGroup:   lbSG,
-				ToPort:        fi.PtrTo(int64(8443)),
+				ToPort:        fi.PtrTo(int32(8443)),
 			}
 			c.AddTask(t)
 		}
@@ -550,29 +551,29 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			c.AddTask(&awstasks.SecurityGroupRule{
 				Name:          fi.PtrTo(fmt.Sprintf("https-elb-to-master%s", suffix)),
 				Lifecycle:     b.SecurityLifecycle,
-				FromPort:      fi.PtrTo(int64(443)),
+				FromPort:      fi.PtrTo(int32(443)),
 				Protocol:      fi.PtrTo("tcp"),
 				SecurityGroup: masterGroup.Task,
 				SourceGroup:   lbSG,
-				ToPort:        fi.PtrTo(int64(443)),
+				ToPort:        fi.PtrTo(int32(443)),
 			})
 			c.AddTask(&awstasks.SecurityGroupRule{
 				Name:          fi.PtrTo(fmt.Sprintf("icmp-pmtu-elb-to-cp%s", suffix)),
 				Lifecycle:     b.SecurityLifecycle,
-				FromPort:      fi.PtrTo(int64(3)),
+				FromPort:      fi.PtrTo(int32(3)),
 				Protocol:      fi.PtrTo("icmp"),
 				SecurityGroup: masterGroup.Task,
 				SourceGroup:   lbSG,
-				ToPort:        fi.PtrTo(int64(4)),
+				ToPort:        fi.PtrTo(int32(4)),
 			})
 			c.AddTask(&awstasks.SecurityGroupRule{
 				Name:          fi.PtrTo(fmt.Sprintf("icmp-pmtu-cp%s-to-elb", suffix)),
 				Lifecycle:     b.SecurityLifecycle,
-				FromPort:      fi.PtrTo(int64(3)),
+				FromPort:      fi.PtrTo(int32(3)),
 				Protocol:      fi.PtrTo("icmp"),
 				SecurityGroup: lbSG,
 				SourceGroup:   masterGroup.Task,
-				ToPort:        fi.PtrTo(int64(4)),
+				ToPort:        fi.PtrTo(int32(4)),
 			})
 			if b.Cluster.UsesNoneDNS() {
 				nlb.WellKnownServices = append(nlb.WellKnownServices, wellknownservices.KopsController)
@@ -581,10 +582,10 @@ func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 				c.AddTask(&awstasks.SecurityGroupRule{
 					Name:          fi.PtrTo(fmt.Sprintf("kops-controller-elb-to-cp%s", suffix)),
 					Lifecycle:     b.SecurityLifecycle,
-					FromPort:      fi.PtrTo(int64(wellknownports.KopsControllerPort)),
+					FromPort:      fi.PtrTo(int32(wellknownports.KopsControllerPort)),
 					Protocol:      fi.PtrTo("tcp"),
 					SecurityGroup: masterGroup.Task,
-					ToPort:        fi.PtrTo(int64(wellknownports.KopsControllerPort)),
+					ToPort:        fi.PtrTo(int32(wellknownports.KopsControllerPort)),
 					SourceGroup:   lbSG,
 				})
 			}
