@@ -18,6 +18,7 @@ package gcemodel
 
 import (
 	"fmt"
+	"slices"
 	"strings"
 
 	"k8s.io/klog/v2"
@@ -124,6 +125,30 @@ func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.CloudupModelB
 				if strings.HasPrefix(ig.Spec.Image, "cos-cloud/") {
 					autoscalerEnvVars = "os_distribution=cos;arch=amd64;os=linux"
 				}
+
+				if len(ig.Spec.NodeLabels) > 0 {
+					var nodeLabels string
+					sortedLabelKeys := make([]string, len(ig.Spec.NodeLabels))
+					i := 0
+					for k := range ig.Spec.NodeLabels {
+						sortedLabelKeys[i] = k
+						i++
+					}
+					slices.SortStableFunc(sortedLabelKeys, func(a, b string) int {
+						return strings.Compare(a, b)
+					})
+					for _, k := range sortedLabelKeys {
+						nodeLabels += k + "=" + ig.Spec.NodeLabels[k] + ","
+					}
+					nodeLabels, _ = strings.CutSuffix(nodeLabels, ",")
+
+					autoscalerEnvVars += ";node_labels=" + nodeLabels
+				}
+
+				if len(ig.Spec.Taints) > 0 {
+					autoscalerEnvVars += ";node_taints=" + strings.Join(ig.Spec.Taints, ",")
+				}
+
 				t.Metadata["kube-env"] = fi.NewStringResource("AUTOSCALER_ENV_VARS: " + autoscalerEnvVars)
 			}
 
@@ -184,11 +209,11 @@ func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.CloudupModelB
 			roleLabel := gce.GceLabelNameRolePrefix + ig.Spec.Role.ToLowerString()
 			t.Labels = map[string]string{
 				clusterLabel.Key:              clusterLabel.Value,
-				roleLabel:                     "",
+				roleLabel:                     ig.Spec.Role.ToLowerString(),
 				gce.GceLabelNameInstanceGroup: ig.ObjectMeta.Name,
 			}
 			if ig.Spec.Role == kops.InstanceGroupRoleControlPlane {
-				t.Labels[gce.GceLabelNameRolePrefix+"master"] = ""
+				t.Labels[gce.GceLabelNameRolePrefix+"master"] = "master"
 			}
 
 			if gce.UsesIPAliases(b.Cluster) {
@@ -313,6 +338,7 @@ func (b *AutoscalingGroupModelBuilder) Build(c *fi.CloudupModelBuilderContext) e
 				Lifecycle:                   b.Lifecycle,
 				Zone:                        s(zone),
 				TargetSize:                  fi.PtrTo(int64(targetSize)),
+				UpdatePolicy:                &gcetasks.UpdatePolicy{MinimalAction: "REPLACE", Type: "OPPORTUNISTIC"},
 				BaseInstanceName:            s(ig.ObjectMeta.Name),
 				InstanceTemplate:            instanceTemplate,
 				ListManagedInstancesResults: "PAGINATED",
