@@ -82,7 +82,7 @@ func (b *ServiceAccountsBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			role = kops.InstanceGroupRoleControlPlane
 		}
 
-		if err := b.addInstanceGroupServiceAccountPermissions(c, *serviceAccount.Email, role); err != nil {
+		if err := b.addInstanceGroupServiceAccountPermissions(c, serviceAccount, role); err != nil {
 			return err
 		}
 	}
@@ -90,8 +90,7 @@ func (b *ServiceAccountsBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 	return nil
 }
 
-func (b *ServiceAccountsBuilder) addInstanceGroupServiceAccountPermissions(c *fi.CloudupModelBuilderContext, serviceAccountEmail string, role kops.InstanceGroupRole) error {
-	member := "serviceAccount:" + serviceAccountEmail
+func (b *ServiceAccountsBuilder) addInstanceGroupServiceAccountPermissions(c *fi.CloudupModelBuilderContext, serviceAccount *gcetasks.ServiceAccount, role kops.InstanceGroupRole) error {
 
 	// Ideally we would use a custom role here, but the deletion of a custom role takes 7 days,
 	// which means we can't easily recycle cluster names.
@@ -104,9 +103,9 @@ func (b *ServiceAccountsBuilder) addInstanceGroupServiceAccountPermissions(c *fi
 			Name:      s("serviceaccount-control-plane"),
 			Lifecycle: b.Lifecycle,
 
-			Project: s(b.ProjectID),
-			Member:  s(member),
-			Role:    s("roles/container.serviceAgent"),
+			Project:              s(b.ProjectID),
+			MemberServiceAccount: serviceAccount,
+			Role:                 s("roles/container.serviceAgent"),
 		})
 
 	case kops.InstanceGroupRoleNode:
@@ -120,9 +119,9 @@ func (b *ServiceAccountsBuilder) addInstanceGroupServiceAccountPermissions(c *fi
 			Name:      s("serviceaccount-nodes"),
 			Lifecycle: b.Lifecycle,
 
-			Project: s(b.ProjectID),
-			Member:  s(member),
-			Role:    s("roles/compute.viewer"),
+			Project:              s(b.ProjectID),
+			MemberServiceAccount: serviceAccount,
+			Role:                 s("roles/compute.viewer"),
 		})
 	}
 	return nil
