@@ -69,10 +69,8 @@ type KeysetItem struct {
 
 // KeystoreReader contains just the functions we need to consume keypairs, not to update them.
 type KeystoreReader interface {
-	pki.Keystore
-
-	// FindKeyset finds a Keyset.
-	FindKeyset(name string) (*Keyset, error)
+	// FindKeyset finds a Keyset.  If the keyset is not found, it returns (nil, nil).
+	FindKeyset(ctx context.Context, name string) (*Keyset, error)
 }
 
 // Keystore contains just the functions we need to issue keypairs, not to list / manage them
@@ -111,18 +109,6 @@ type SSHCredentialStore interface {
 	FindSSHPublicKeys() ([]*kops.SSHCredential, error)
 }
 
-// FindPrimaryKeypair is a common implementation of pki.FindPrimaryKeypair.
-func FindPrimaryKeypair(c Keystore, name string) (*pki.Certificate, *pki.PrivateKey, error) {
-	keyset, err := c.FindKeyset(name)
-	if err != nil {
-		return nil, nil, err
-	}
-	if keyset == nil || keyset.Primary == nil {
-		return nil, nil, nil
-	}
-	return keyset.Primary.Certificate, keyset.Primary.PrivateKey, nil
-}
-
 // KeysetItemIdOlder returns whether the KeysetItem Id a is older than b.
 func KeysetItemIdOlder(a, b string) bool {
 	aVersion, aOk := big.NewInt(0).SetString(a, 10)
@@ -254,3 +240,22 @@ func (k *Keyset) AddItem(cert *pki.Certificate, privateKey *pki.PrivateKey, prim
 
 	return ki, nil
 }
+
+type pkiKeystoreAdapter struct {
+	reader KeystoreReader
+}
+
+func (p pkiKeystoreAdapter) FindPrimaryKeypair(ctx context.Context, name string) (*pki.Certificate, *pki.PrivateKey, error) {
+	keyset, err := p.reader.FindKeyset(ctx, name)
+	if err != nil {
+		return nil, nil, err
+	}
+	if keyset == nil || keyset.Primary == nil {
+		return nil, nil, nil
+	}
+	return keyset.Primary.Certificate, keyset.Primary.PrivateKey, nil
+}
+
+func NewPKIKeystoreAdapter(reader KeystoreReader) pki.Keystore {
+	return &pkiKeystoreAdapter{reader: reader}
+}
