@@ -35,6 +35,7 @@ type Disk struct {
 	ResourceGroup *ResourceGroup
 	SizeGB        *int32
 	Tags          map[string]*string
+	VolumeType    *compute.DiskStorageAccountTypes
 	Zones         []*string
 }
 
@@ -77,6 +78,9 @@ func (d *Disk) Find(c *fi.CloudupContext) (*Disk, error) {
 		Tags:   found.Tags,
 		Zones:  found.Zones,
 	}
+	if found.SKU != nil && found.SKU.Name != nil {
+		disk.VolumeType = found.SKU.Name
+	}
 	if found.Properties != nil {
 		disk.SizeGB = found.Properties.DiskSizeGB
 	}
@@ -129,7 +133,7 @@ func (*Disk) RenderAzure(t *azure.AzureAPITarget, a, e, changes *Disk) error {
 			DiskSizeGB: e.SizeGB,
 		},
 		SKU: &compute.DiskSKU{
-			Name: to.Ptr(compute.DiskStorageAccountTypesStandardSSDLRS),
+			Name: e.VolumeType,
 		},
 		Tags:  e.Tags,
 		Zones: e.Zones,
