@@ -67,6 +67,7 @@ type Ocean struct {
 	SpreadNodesBy                   *string
 	AvailabilityVsCost              *string
 	ResourceTagSpecificationVolumes *bool
+	AutoScalerAggressiveScaleDown   *bool
 }
 
 var (
@@ -135,7 +136,7 @@ func (o *Ocean) find(svc spotinst.InstanceGroupService) (*aws.Cluster, error) {
 var _ fi.CloudupHasCheckExisting = &Ocean{}
 
 func (o *Ocean) Find(c *fi.CloudupContext) (*Ocean, error) {
-	cloud := c.T.Cloud.(awsup.AWSCloud)
+	cloud := awsup.GetCloud(c)
 
 	ocean, err := o.find(cloud.Spotinst().Ocean())
 	if err != nil {
@@ -324,9 +325,14 @@ func (o *Ocean) Find(c *fi.CloudupContext) (*Ocean, error) {
 
 			// Scale down.
 			if down := ocean.AutoScaler.Down; down != nil {
-				actual.AutoScalerOpts.Down = &AutoScalerDownOpts{
-					MaxPercentage:     down.MaxScaleDownPercentage,
-					EvaluationPeriods: down.EvaluationPeriods,
+				if down.MaxScaleDownPercentage != nil || down.EvaluationPeriods != nil {
+					actual.AutoScalerOpts.Down = &AutoScalerDownOpts{
+						MaxPercentage:     down.MaxScaleDownPercentage,
+						EvaluationPeriods: down.EvaluationPeriods,
+					}
+				}
+				if down.AggressiveScaleDown != nil {
+					actual.AutoScalerAggressiveScaleDown = down.AggressiveScaleDown.IsEnabled
 				}
 			}
 
@@ -347,7 +353,7 @@ func (o *Ocean) Find(c *fi.CloudupContext) (*Ocean, error) {
 }
 
 func (o *Ocean) CheckExisting(c *fi.CloudupContext) bool {
-	cloud := c.T.Cloud.(awsup.AWSCloud)
+	cloud := awsup.GetCloud(c)
 	ocean, err := o.find(cloud.Spotinst().Ocean())
 	return err == nil && ocean != nil
 }
@@ -585,6 +591,16 @@ func (_ *Ocean) create(cloud awsup.AWSCloud, a, e, changes *Ocean) error {
 						MaxMemoryGiB: limits.MaxMemory,
 					}
 				}
+				// create AutoScalerAggressiveScaleDown
+				{
+					if e.AutoScalerAggressiveScaleDown != nil {
+						aggressiveScaleDown := new(aws.AggressiveScaleDown)
+						if down := autoScaler.Down; down == nil {
+							autoScaler.Down = new(aws.AutoScalerDown)
+						}
+						autoScaler.Down.SetAggressiveScaleDown(aggressiveScaleDown.SetIsEnabled(fi.PtrTo(*e.AutoScalerAggressiveScaleDown)))
+					}
+				}
 
 				ocean.SetAutoScaler(autoScaler)
 			}
@@ -1084,6 +1100,15 @@ func (_ *Ocean) update(cloud awsup.AWSCloud, a, e, changes *Ocean) error {
 				} else if a.AutoScalerOpts.ResourceLimits != nil {
 					autoScaler.SetResourceLimits(nil)
 				}
+				// AutoScaler aggressive scale down
+				if changes.AutoScalerAggressiveScaleDown != nil {
+					aggressiveScaleDown := new(aws.AggressiveScaleDown)
+					if down := autoScaler.Down; down == nil {
+						autoScaler.Down = new(aws.AutoScalerDown)
+					}
+					autoScaler.Down.SetAggressiveScaleDown(aggressiveScaleDown.SetIsEnabled(fi.PtrTo(*changes.AutoScalerAggressiveScaleDown)))
+					changes.AutoScalerAggressiveScaleDown = nil
+				}
 
 				ocean.SetAutoScaler(autoScaler)
 				changed = true
