@@ -116,7 +116,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 		return defaultValue
 	}
 
-	dest["GetCloudProvider"] = cluster.Spec.GetCloudProvider
+	dest["GetCloudProvider"] = cluster.GetCloudProvider
 	dest["GetInstanceGroup"] = tf.GetInstanceGroup
 	dest["GetNodeInstanceGroups"] = tf.GetNodeInstanceGroups
 	dest["GetClusterAutoscalerNodeGroups"] = tf.GetClusterAutoscalerNodeGroups
@@ -174,7 +174,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	dest["DNSControllerEnvs"] = tf.DNSControllerEnvs
 	dest["ProxyEnv"] = tf.ProxyEnv
 
-	dest["KopsSystemEnv"] = tf.KopsSystemEnv
+	dest["KopsControllerEnv"] = tf.KopsControllerEnv
 
 	dest["DO_TOKEN"] = func() string {
 		return os.Getenv("DIGITALOCEAN_ACCESS_TOKEN")
@@ -289,7 +289,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 			if c.IPIPMode != "" {
 				return c.IPIPMode
 			}
-			if cluster.Spec.GetCloudProvider() == kops.CloudProviderOpenstack {
+			if cluster.GetCloudProvider() == kops.CloudProviderOpenstack {
 				return "Always"
 			}
 			return "CrossSubnet"
@@ -303,6 +303,15 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 			}
 			return "CrossSubnet"
 		}
+		dest["CalicoIPv6PoolVXLANMode"] = func() string {
+			if c.EncapsulationMode != "vxlan" {
+				return "Never"
+			}
+			if c.VXLANMode != "" {
+				return c.VXLANMode
+			}
+			return "Never"
+		}
 	}
 
 	if cluster.Spec.Networking.Cilium != nil {
@@ -522,8 +531,8 @@ func (tf *TemplateFunctions) CloudControllerConfigArgv() ([]string, error) {
 
 	// take the cloud provider value from clusterSpec if unset
 	if cluster.Spec.ExternalCloudControllerManager.CloudProvider == "" {
-		if cluster.Spec.GetCloudProvider() != "" {
-			argv = append(argv, fmt.Sprintf("--cloud-provider=%s", cluster.Spec.GetCloudProvider()))
+		if cluster.GetCloudProvider() != "" {
+			argv = append(argv, fmt.Sprintf("--cloud-provider=%s", cluster.GetCloudProvider()))
 		} else {
 			return nil, fmt.Errorf("Cloud Provider is not set")
 		}
@@ -534,7 +543,7 @@ func (tf *TemplateFunctions) CloudControllerConfigArgv() ([]string, error) {
 		argv = append(argv, fmt.Sprintf("--use-service-account-credentials=%t", true))
 	}
 
-	if cluster.Spec.GetCloudProvider() != kops.CloudProviderHetzner {
+	if cluster.GetCloudProvider() != kops.CloudProviderHetzner {
 		argv = append(argv, "--cloud-config=/etc/kubernetes/cloud.config")
 	}
 
@@ -616,7 +625,7 @@ func (tf *TemplateFunctions) DNSControllerArgv() ([]string, error) {
 			argv = append(argv, fmt.Sprintf("--gossip-seed-secondary=127.0.0.1:%d", wellknownports.ProtokubeGossipMemberlist))
 		}
 	} else {
-		switch cluster.Spec.GetCloudProvider() {
+		switch cluster.GetCloudProvider() {
 		case kops.CloudProviderAWS:
 			if strings.HasPrefix(os.Getenv("AWS_REGION"), "cn-") {
 				argv = append(argv, "--dns=gossip")
@@ -633,7 +642,7 @@ func (tf *TemplateFunctions) DNSControllerArgv() ([]string, error) {
 			argv = append(argv, "--dns=scaleway")
 
 		default:
-			return nil, fmt.Errorf("unhandled cloudprovider %q", cluster.Spec.GetCloudProvider())
+			return nil, fmt.Errorf("unhandled cloudprovider %q", cluster.GetCloudProvider())
 		}
 	}
 
@@ -668,7 +677,7 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 
 	config := &kopscontrollerconfig.Options{
 		ClusterName: cluster.Name,
-		Cloud:       string(cluster.Spec.GetCloudProvider()),
+		Cloud:       string(cluster.GetCloudProvider()),
 		ConfigBase:  cluster.Spec.ConfigStore.Base,
 		SecretStore: cluster.Spec.ConfigStore.Secrets,
 	}
@@ -705,10 +714,10 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 			config.Server.PKI = &pkibootstrap.Options{}
 		}
 
-		switch cluster.Spec.GetCloudProvider() {
+		switch cluster.GetCloudProvider() {
 		case kops.CloudProviderAWS:
 			nodesRoles := sets.String{}
-			for _, ig := range tf.InstanceGroups {
+			for _, ig := range tf.AllInstanceGroups {
 				if ig.Spec.Role == kops.InstanceGroupRoleNode || ig.Spec.Role == kops.InstanceGroupRoleAPIServer {
 					profile, err := tf.LinkToIAMInstanceProfile(ig)
 					if err != nil {
@@ -764,8 +773,12 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 				ClusterName: tf.ClusterName(),
 			}
 
+		case kops.CloudProviderMetal:
+			// Use crypto public/private keys for Metal
+			config.Server.PKI = &pkibootstrap.Options{}
+
 		default:
-			return "", fmt.Errorf("unsupported cloud provider %s", cluster.Spec.GetCloudProvider())
+			return "", fmt.Errorf("unsupported cloud provider %s", cluster.GetCloudProvider())
 		}
 	}
 
@@ -806,7 +819,7 @@ func (tf *TemplateFunctions) ExternalDNSArgv() ([]string, error) {
 
 	var argv []string
 
-	cloudProvider := cluster.Spec.GetCloudProvider()
+	cloudProvider := cluster.GetCloudProvider()
 
 	switch cloudProvider {
 	case kops.CloudProviderAWS:
@@ -818,7 +831,7 @@ func (tf *TemplateFunctions) ExternalDNSArgv() ([]string, error) {
 		argv = append(argv, "--provider=google")
 		argv = append(argv, "--google-project="+project)
 	default:
-		return nil, fmt.Errorf("unhandled cloudprovider %q", cluster.Spec.GetCloudProvider())
+		return nil, fmt.Errorf("unhandled cloudprovider %q", cluster.GetCloudProvider())
 	}
 
 	argv = append(argv, "--events")
@@ -839,7 +852,7 @@ func (tf *TemplateFunctions) ExternalDNSArgv() ([]string, error) {
 }
 
 func (tf *TemplateFunctions) DNSControllerEnvs() map[string]string {
-	if tf.Cluster.Spec.GetCloudProvider() != kops.CloudProviderOpenstack {
+	if tf.Cluster.GetCloudProvider() != kops.CloudProviderOpenstack {
 		return nil
 	}
 	envs := env.BuildSystemComponentEnvVars(&tf.Cluster.Spec)
@@ -879,14 +892,20 @@ func (tf *TemplateFunctions) ProxyEnv() map[string]string {
 	return envs
 }
 
-// KopsSystemEnv builds the env vars for a system component
-func (tf *TemplateFunctions) KopsSystemEnv() []corev1.EnvVar {
+// KopsControllerEnv builds the env vars for the kops-controller component
+func (tf *TemplateFunctions) KopsControllerEnv() []corev1.EnvVar {
 	envMap := env.BuildSystemComponentEnvVars(&tf.Cluster.Spec)
 
+	// kops-controller needs the KOPS_RUN_TOO_NEW_VERSION env var to run newer versions of kubernetes
+	// (if building bootstrap configuration on the fly)
+	if v := os.Getenv("KOPS_RUN_TOO_NEW_VERSION"); v != "" {
+		envMap["KOPS_RUN_TOO_NEW_VERSION"] = v
+	}
+
 	return envMap.ToEnvVars()
 }
 
-// OpenStackCCM returns OpenStack external cloud controller manager current image
+// OpenStackCCMTag returns OpenStack external cloud controller manager current image
 // with tag specified to k8s version
 func (tf *TemplateFunctions) OpenStackCCMTag() string {
 	var tag string
@@ -894,11 +913,7 @@ func (tf *TemplateFunctions) OpenStackCCMTag() string {
 	if err != nil {
 		tag = "latest"
 	} else {
-		if parsed.Minor == 25 {
-			tag = "v1.25.5"
-		} else if parsed.Minor == 26 {
-			tag = "v1.26.2"
-		} else if parsed.Minor == 27 {
+		if parsed.Minor == 27 {
 			tag = "v1.27.1"
 		} else {
 			// otherwise we use always .0 ccm image, if needed that can be overrided using clusterspec
@@ -908,7 +923,7 @@ func (tf *TemplateFunctions) OpenStackCCMTag() string {
 	return tag
 }
 
-// OpenStackCSI returns OpenStack csi current image
+// OpenStackCSITag returns OpenStack csi current image
 // with tag specified to k8s version
 func (tf *TemplateFunctions) OpenStackCSITag() string {
 	var tag string
@@ -916,11 +931,7 @@ func (tf *TemplateFunctions) OpenStackCSITag() string {
 	if err != nil {
 		tag = "latest"
 	} else {
-		if parsed.Minor == 25 {
-			tag = "v1.25.5"
-		} else if parsed.Minor == 26 {
-			tag = "v1.26.2"
-		} else if parsed.Minor == 27 {
+		if parsed.Minor == 27 {
 			tag = "v1.27.1"
 		} else {
 			// otherwise we use always .0 csi image, if needed that can be overrided using cloud config spec
@@ -959,7 +970,7 @@ func (tf *TemplateFunctions) GetClusterAutoscalerNodeGroups() map[string]Cluster
 				MinSize:   fi.ValueOf(ig.Spec.MinSize),
 				MaxSize:   fi.ValueOf(ig.Spec.MaxSize),
 			}
-			if cluster.Spec.GetCloudProvider() == kops.CloudProviderGCE {
+			if cluster.GetCloudProvider() == kops.CloudProviderGCE {
 				cloud := tf.cloud.(gce.GCECloud)
 				format := "https://www.googleapis.com/compute/v1/projects/%s/zones/%s/instanceGroups/%s"
 				group.Other = fmt.Sprintf(format, cloud.Project(), ig.Spec.Zones[0], gce.NameForInstanceGroupManager(cluster.ObjectMeta.Name, ig.ObjectMeta.Name, ig.Spec.Zones[0]))
