@@ -26,6 +26,7 @@ import (
 	api "k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/validation"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/util/pkg/vfs"
 )
 
 const testAWSRegion = "us-test-1"
@@ -34,7 +35,7 @@ func buildDefaultCluster(t *testing.T) *api.Cluster {
 	ctx := context.TODO()
 	cloud, c := buildMinimalCluster()
 
-	err := PerformAssignments(c, cloud)
+	err := PerformAssignments(c, vfs.Context, cloud)
 	if err != nil {
 		t.Fatalf("error from PerformAssignments: %v", err)
 	}
@@ -85,11 +86,11 @@ func buildDefaultCluster(t *testing.T) *api.Cluster {
 
 func TestValidateFull_Default_Validates(t *testing.T) {
 	c := buildDefaultCluster(t)
-	if errs := validation.ValidateCluster(c, false); len(errs) != 0 {
+	if errs := validation.ValidateCluster(c, false, vfs.Context); len(errs) != 0 {
 		klog.Infof("Cluster: %v", c)
 		t.Fatalf("Validate gave unexpected error (strict=false): %v", errs.ToAggregate())
 	}
-	if errs := validation.ValidateCluster(c, true); len(errs) != 0 {
+	if errs := validation.ValidateCluster(c, true, vfs.Context); len(errs) != 0 {
 		t.Fatalf("Validate gave unexpected error (strict=true): %v", errs.ToAggregate())
 	}
 }
@@ -199,7 +200,7 @@ func TestValidate_ContainerRegistry_and_ContainerProxy_exclusivity(t *testing.T)
 }
 
 func expectErrorFromValidate(t *testing.T, c *api.Cluster, message string) {
-	errs := validation.ValidateCluster(c, false)
+	errs := validation.ValidateCluster(c, false, vfs.Context)
 	if len(errs) == 0 {
 		t.Fatalf("Expected error from Validate")
 	}
@@ -210,7 +211,7 @@ func expectErrorFromValidate(t *testing.T, c *api.Cluster, message string) {
 }
 
 func expectNoErrorFromValidate(t *testing.T, c *api.Cluster) {
-	errs := validation.ValidateCluster(c, false)
+	errs := validation.ValidateCluster(c, false, vfs.Context)
 	if len(errs) != 0 {
 		t.Fatalf("Unexpected error from Validate: %v", errs.ToAggregate())
 	}
